@@ -9,7 +9,7 @@ pub(crate) fn get_impl_for_logic_interface(input: &syn::DeriveInput) -> Result<T
     let fields = get_field_names(input)?;
     let field_types = get_field_types(input)?;
     let link = get_link(fields.clone())?;
-    let link_hdl = get_link_hdl(fields.clone())?;
+    let link_hdl = get_link_hdl(fields.clone(), field_types.clone())?;
     let update_all = get_update_all(fields.clone())?;
     let has_changed = get_has_changed(fields.clone())?;
     let connect_all = get_connect_all(fields.clone())?;
@@ -79,12 +79,12 @@ fn get_link(fields: Vec<TS>) -> Result<TS> {
     })
 }
 
-fn get_link_hdl(fields: Vec<TS>) -> Result<TS> {
+fn get_link_hdl(fields: Vec<TS>, field_types: Vec<TS>) -> Result<TS> {
     let fields_as_strings = fields.iter().map(|x| x.to_string()).collect::<Vec<_>>();
     Ok(quote! {
-        fn link_hdl(&self, my_name: &str, this: &str, that: &str) -> Vec<ast::VerilogLink> {
+        fn link_hdl(my_name: &str, this: &str, that: &str) -> Vec<ast::VerilogLink> {
             let mut ret = vec![];
-            #(ret.append(&mut self.#fields.link_hdl(#fields_as_strings, this, that));)*
+            #(ret.extend(<#field_types>::link_hdl(#fields_as_strings, this, that));)*
             ret
         }
     })
